Scatter plot of a single cell-cell vector, involving features of interest. Returns a ggplot object, colored by mechanism. Points are labeled if above label.threshold on both x- and y-axes.
Usage
CellCellScatter(
connectome,
sources.include,
targets.include,
label.threshold = 1,
weight.attribute = "weight_sc",
...
)Arguments
- connectome
A connectomic edgelist
- sources.include
Source nodes of interest. Output will be limited to edges coming from these sources.
- targets.include
Target nodes of interest. Output will be limited to edges landing on these targets.
- label.threshold
Threshold for labeling of plot, applied to both x- and y- axes. Defaults to 1.
- weight.attribute
Column to use to define edgeweights for network analysis. 'weight_sc or weight_norm'. Defaults to 'weight_sc'
- ...
Arguments passed to FilterConnectome