Currently in beta testing. A Circos Plot for a differential edgelist made using DifferentialConnectome. Note that negative log fold changes cannot be plotted; therefore, this plot uses the 'score' for the differential comparison, which is always positive in proportion to perturbation.
Usage
CircosDiff(
differential.connectome,
features = NULL,
sources.include = NULL,
targets.include = NULL,
min.score = NULL,
min.pct = NULL,
verbose = TRUE,
infinity.to.max = TRUE,
edge.color.by.source = TRUE,
cols.use = NULL,
lab.cex = 1,
title = NULL,
small.gap = 1,
big.gap = 10
)Arguments
- differential.connectome
A differential connectome, made with DifferentialConnectome. May be filtered as desired prior to plotting.
- features
Gene of interest. Output will be limited to edges including these specific genes.
- sources.include
Source nodes of interest. Output will be limited to edges coming from these sources.
- targets.include
Target nodes of interest. Output will be limited to edges landing on these targets.
- min.score
Default NULL. Will limit output to edges with a differential score greater than this value.
- min.pct
Default NULL. Threshold to return clusterwise observations for both ligand and receptor. Only needs to be satisfied in connect.1 OR in connect.2.
- verbose
Whether to output feedback to user
- infinity.to.max
Default TRUE. If TRUE, will create a pseudo value to replace values of "Inf"
- edge.color.by.source
Default TRUE - edges will be colored by their source cell type. If false, edges will be colored by receiving cell instead.
- cols.use
Optional. Colors for plotting nodes.
- lab.cex
Text size for gene names
- title
Character string for title of plot.
- small.gap
Default 1. Amount of distance between sectors. If the number of edges is very large, this will have to be reduced in size.
- big.gap
Default 10. Amount of distance between the source cells and the target cells (top and bottom arc of graph). If the number of edges is very large, this can be reduced in size in addition to 'small.gap'