Plotting function to make a DotPlot of differential edges for a network comparison. This function first finds all edges meeting the desired thresholding criteria, and then plots complete information regarding all mechanisms and celltype vectors implicated.
Usage
DiffEdgeDotPlot(
differential.connectome,
features = NULL,
sources.include = NULL,
targets.include = NULL,
min.score = NULL,
min.pct = NULL,
verbose = TRUE,
infinity.to.max = TRUE,
...
)Arguments
- differential.connectome
A differential connectome object
- features
Gene of interest. Output will be limited to edges including these specific genes.
- sources.include
Source nodes of interest. Output will be limited to edges coming from these sources.
- targets.include
Target nodes of interest. Output will be limited to edges landing on these targets.
- min.score
Default NULL. Will limit output to edges with a differential score greater than this value.
- min.pct
Default NULL. Threshold to return clusterwise observations for both ligand and receptor. Only needs to be satisfied in connect.1 OR in connect.2.
- verbose
Whether to output feedback to user
- infinity.to.max
Default TRUE. If TRUE, will create a pseudo value to replace values of "Inf"
- ...
Additional arguments (not currently used)