Currently in beta testing. Creates a fold-change connectome from two input connectomes, generally unfiltered. Must be node-aligned, from the same reference mapping, and unfiltered. ('edge' columns must contain identical entries, though not necessarily in the same order.)
Usage
DifferentialConnectome(connect.ref, connect.test, min.pct = NULL)
Arguments
- connect.ref
A connectome from a system
- connect.test
A connectome from a different system, to be compared to connect.ref
- min.pct
Default NULL. Threshold to return clusterwise observations for both ligand and receptor. Only needs to be satisfied in connect.ref OR in connect.test.