Currently in beta testing. Creates x3 aligned heatmaps allowing visualization of ligand, receptor, and perturbation scores for a given cell-system of interest.
Usage
DifferentialScoringPlot(
differential.connectome,
features = NULL,
sources.include = NULL,
targets.include = NULL,
min.score = NULL,
min.pct = NULL,
verbose = TRUE,
infinity.to.max = TRUE,
aligned = FALSE
)Arguments
- differential.connectome
A differential connectome, made with DifferentialConnectome. May be filtered as desired prior to plotting.
- features
Gene of interest. Output will be limited to edges including these specific genes.
- sources.include
Source nodes of interest. Output will be limited to edges coming from these sources.
- targets.include
Target nodes of interest. Output will be limited to edges landing on these targets.
- min.score
Default NULL. Will limit output to edges with a differential score greater than this value.
- min.pct
Default NULL. Threshold to return clusterwise observations for both ligand and receptor. Only needs to be satisfied in connect.1 OR in connect.2.
- verbose
Whether to output feedback to user
- infinity.to.max
Default TRUE. If TRUE, will create a pseudo value to replace values of "Inf"
- aligned
Default FALSE. If TRUE, will create edge-aligned heatmaps (duplicate rows and columns in first two plots, to dimension map all three plots)