Skip to contents

Plotting function to make a DotPlot of edges within a specified network. This function first finds all edges meeting the desired thresholding criteria, and then plots complete information regarding all mechanisms and celltype vectors implicated.

Usage

EdgeDotPlot(connectome, ...)

Arguments

connectome

A connectomic object

...

Arguments passed to FilterConnectome