Skip to contents

Splits a Seurat object using SplitObject, but makes sure that for each identity, an even number of cells are sampled.

Usage

EvenSplit(object, split.by)

Arguments

object

A Seurat object

split.by

Parameter by which to split the object (e.g., a metadata column name)

Value

A named list of Seurat objects, one for each level of split.by