Filters a connectomic edgelist output from CreateConnectome according to user inputs. Defaults are set to reasonable initial parameters for data clean-up and exploration.
Usage
FilterConnectome(
connectome,
min.pct = NULL,
max.p = NULL,
min.DOR = NULL,
min.exp = NULL,
min.z = NULL,
modes.include = NULL,
sources.include = NULL,
targets.include = NULL,
mechanisms.include = NULL,
features = NULL,
verbose = TRUE,
remove.na = FALSE
)Arguments
- connectome
A connectomic edgelist output from CreateConnectome
- min.pct
Minimum fraction of cells within a given cluster expressing the ligand or receptor.
- max.p
Maximum p-value for ligand and receptor. Filtration on this column requires prior p-value calculation.
- min.DOR
Minimum log-normalized Diagnostic Odds Ratio for the ligand or receptor for its cell type within an edge.
- min.exp
Minimum normalized expression level of ligand and receptor.
- min.z
Minimum z-score for ligand and receptor.
- modes.include
String or vector signifying mode(s) of interest in include.
- sources.include
Source nodes of interest. Output will be limited to edges coming from these sources.
- targets.include
Target nodes of interest. Output will be limited to edges landing on these targets.
- mechanisms.include
Ligand - Receptor pairs of interest. The character string should match entries in the 'pair' column of the connectome.
- features
Genes of interest. Output will be limited to edges including these specific genes (as ligand or receptor).
- verbose
Whether to output feedback to user
- remove.na
Whether to remove edges containing 'NA' (no mapping to original object - only useful if investigating orphan ligands and receptors)