Skip to contents

Creates a network plot of a connectomic object. Wrapper for igraph functionality.

Usage

NetworkPlot(
  connectome,
  weight.attribute = "weight_sc",
  title = NULL,
  cols.use = NULL,
  include.all.nodes = FALSE,
  min.z = NULL,
  mar = 1.5,
  layout = "circle",
  edge.label.cex = 0.4,
  ...
)

Arguments

connectome

A connectomic object, ideally filtered to only edges of interest.

weight.attribute

Column to use to define edgeweights for network analysis. 'weight_sc' or 'weight_norm'. Defaults to 'weight_sc'

title

Description of the network being plotted

cols.use

Optional. Colors for plotting nodes.

include.all.nodes

If TRUE, include all nodes from original connectome even after filtering. Default FALSE.

min.z

Minimum z-score for ligand and receptor.

mar

Default 1.5. Symmetric margin around plot.

layout

Layout algorithm. Either "circle" (default) or "force.directed".

edge.label.cex

Text size for edge labels. Default 0.4.

...

Arguments passed to FilterConnectome

Value

A recorded plot object