Scatter plot of signaling vectors involving features of interest. Returns a ggplot object, colored by mechanism, labeled by cell-cell vector.
Usage
SignalScatter(
connectome,
features,
label.threshold = 1,
weight.attribute = "weight_sc",
...
)Arguments
- connectome
A connectomic edgelist
- features
Features of interest
- label.threshold
Threshold for labeling of plot. Sum of receptor score and ligand score must be greater than this number.
- weight.attribute
Column to use to define edgeweights for network analysis. 'weight_sc or weight_norm'. Defaults to 'weight_sc'
- ...
Arguments passed to FilterConnectome