Takes a Seurat object and creates a single-cell connectome (rows are ligand-receptor mechanisms and columns are cell-cell vectors)
Usage
SingleCellConnectome(
object,
LR.database = "fantom5",
species = NULL,
include.putative = TRUE,
include.rejected = FALSE,
max.cells.per.ident = NULL,
min.cells.per.ident = NULL,
slot.use = "data",
weight.definition = "product",
custom.list = NULL,
assay = "RNA",
...
)Arguments
- object
A Seurat object
- LR.database
Accepts either 'fantom5' or 'custom'. If custom, a dataframe must be provided to argument custom.list with the first column equal to ligands, second column equal to associated receptors, and third column equal to desired modal categorizations.
- species
The species of the object that is being processed. Only required if LR.database = 'fantom5', and allows 'human','mouse','rat', or 'pig'
- include.putative
Default TRUE. Includes ligand-receptor pairs deemed putative in FANTOM5 database.
- include.rejected
Default FALSE. If TRUE, includes gene pairs labeled "EXCLUDED" in FANTOM5 database.
- max.cells.per.ident
Default NULL. If a value is input, input object will be downsampled to requested number of cells per identity.
- min.cells.per.ident
Default NULL. If a value is input, only cell populations meeting this threshold will be included in network analysis.
- slot.use
Which data slot to use. Default "data".
- weight.definition
Method for combining ligand and receptor values. Options: "product" (default), "sum", "mean".
- custom.list
Optional. A dataframe for custom mapping, with the first column equal to ligands, second column equal to associated receptors, and third column equal to desired modal categorizations.
- assay
Assay to use. Default "RNA".
- ...
Additional arguments (not currently used)